@@ -35,8 +35,8 @@
 #include <sys/wait.h>
 #include <termios.h>
 
-#include <gnome.h>
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #include <glade/glade.h>
 #include <gconf/gconf-client.h>
 
@@ -49,6 +49,7 @@
 
 #include "gst-auth.h"
 #include "gst-tool.h"
+#include "gst-platform.h"
 
 #define GST_AUTH_RESPONSE_NP 1
 
@@ -103,7 +104,7 @@ gst_auth_wait_child (GstTool *tool)
 			primary_text   = g_strdup_printf (_("Could not run \"%s\""), auth_command);
 			secondary_text = g_strdup (_("Check that you have permissions to run this command"));
 		} else {
-			primary_text   = g_strdup (_("An unexpected error has ocurred"));
+			primary_text   = g_strdup (_("An unexpected error has occurred"));
 			secondary_text = NULL;
 		}
 
@@ -216,7 +217,7 @@ load_glade_common (const gchar *widget)
 }
 
 static void
-gst_auth_get_password (gchar **password)
+gst_auth_get_password (GstTool *tool, gchar **password)
 {
 	GladeXML *xml;
 	gint result;
@@ -229,6 +230,7 @@ gst_auth_get_password (gchar **password)
 	g_assert (password_entry);
 	g_assert (password_dialog);
 
+	gtk_window_set_transient_for (GTK_WINDOW (password_dialog), GTK_WINDOW (tool->main_dialog));
 	gtk_widget_show (password_dialog);
 	gtk_widget_grab_focus (password_entry);
 	result = gtk_dialog_run (GTK_DIALOG (password_dialog));
@@ -289,7 +291,7 @@ gst_auth_do_authentication (GstTool *tool, gchar *args[])
 	result = gst_auth_get_auth_required (tool);
 
 	if (result == GST_AUTH_PASSWORD) {
-		gst_auth_get_password (&password);
+		gst_auth_get_password (tool, &password);
 		gst_tool_write_to_backend (tool, password);
 
 		if (strlen (password) > 0)
